package com.cim.idm.dao;

import com.cim.idm.model.dto.DeliveryRelationDto;
import com.cim.idm.model.po.MaterialReceiveRequest;
import com.cim.idm.model.po.MaterialReceiveRequestDetail;
import com.cim.idm.model.dto.PurchaseDto;
import org.apache.ibatis.annotations.MapKey;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;
import org.springframework.stereotype.Component;

import java.util.List;
import java.util.Map;

@Component
@Mapper
public interface DeliveryDao {

    /**
     * 新增到货单
     */
    int createDelivery(@Param("siteName") String siteName,
                       @Param("receiveRequestName") String receiveRequestName,
                       @Param("receiveRequestType") String receiveRequestType );

    /**
     * 新增到货单关系
     */
    int createRelation(@Param("receiveList") List<DeliveryRelationDto> receiveList);

    /**
     * 绑定采购订单 的 到货单
     */
    int bindDelivery(@Param("siteName") String siteName,
                     @Param("receiveRequestName") String receiveRequestName,
                     @Param("nameList") List<String> nameList);

    /**
     * 获取采购订单
     */
    List<MaterialReceiveRequest> getPurchase(@Param("dto") PurchaseDto dto,
                                             @Param("typeList") List<String> typeList);

    /**
     * 获取入库详情
     */
    @MapKey("storeDetail")
    List<Map<String, Object>> getStoreDetail(@Param("siteName") String siteName,
                                             @Param("nameList") List<String> nameList);

    /**
     * 获取入库批次
     */
    @MapKey("storeCharge")
    List<Map<String, Object>> getStoreCharge(@Param("siteName") String siteName,
                                             @Param("nameList") List<String> nameList);

    /**
     * 根据 key 获取值
     */
    MaterialReceiveRequest getByKey(@Param("siteName") String siteName,
                        @Param("receiveRequestName") String receiveRequestName);

    /**
     * 根据到库单获取采购单名称
     */
    List<MaterialReceiveRequest> getReceiveByDelivery(@Param("siteName") String siteName,
                                      @Param("receiveRequestName") String receiveRequestName);

    /**
     * 根据到库单获取采购单名称
     * @param nameList 到库单
     * @return 采购单名称列表
     */
    List<MaterialReceiveRequestDetail> getReceiveDetail(@Param("nameList") List<String> nameList);
}
