package com.cim.idm.service.Impl;

import com.alibaba.fastjson.JSON;
import com.cim.idm.constants.ReceiveTypeEnums;
import com.cim.idm.dao.DeliveryDao;
import com.cim.idm.model.dto.PageDto;
import com.cim.idm.model.dto.PurchaseDto;
import com.cim.idm.model.dto.DeliveryDto;
import com.cim.idm.model.dto.DeliveryRelationDto;
import com.cim.idm.model.po.MaterialReceiveRequest;
import com.cim.idm.model.po.MaterialReceiveRequestDetail;
import com.cim.idm.service.IDeliveryService;
import com.cim.idm.wmspackage.invoice.management.data.MaterialReceiveRequestKey;
import com.github.pagehelper.PageInfo;
import com.github.pagehelper.page.PageMethod;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

@Service
public class DeliveryServiceImpl implements IDeliveryService {

    @Resource
    private DeliveryDao deliveryDao;

    @Override
    @Transactional
    public String createDelivery(DeliveryDto dto) {
        // 添加到库单
        if (deliveryDao.createDelivery(dto.getSiteName(),
                dto.getReceiveRequestName(), ReceiveTypeEnums.DK.getCode()) <= 0) {
            return "添加到库单失败";
        }
        // 添加到库单关系
        for (DeliveryRelationDto item : dto.getReceiveList()) {
            item.setDeliveryName(dto.getReceiveRequestName());
        }
        if (deliveryDao.createRelation(dto.getReceiveList()) <= 0) {
            return "添加到库单关系失败";
        }
        // 更新采购单到库单字段
        List<String> collect = dto.getDataList().stream()
                .map(MaterialReceiveRequestKey::getReceiveRequestName).collect(Collectors.toList());
        deliveryDao.bindDelivery(dto.getSiteName(), dto.getReceiveRequestName(), collect);
        return "更新成功";
    }

    @Override
    public PageInfo<MaterialReceiveRequest> getPurchase(PageDto dto) {
        PageMethod.startPage(dto.getPageNum(), dto.getPageSize());
        PurchaseDto purchaseDto = JSON.toJavaObject(dto.getParams(), PurchaseDto.class);
        return new PageInfo<>(deliveryDao.getPurchase(purchaseDto, ReceiveTypeEnums.getPurchase()));
    }

    @Override
    public Map<String, Object> getStoreDetail(String siteName, List<String> nameList) {
        Map<String, Object> res = new HashMap<>();
        // 采购单明细
        List<Map<String, Object>> storeDetail = deliveryDao.getStoreDetail(siteName, nameList);
        // 批次
        List<Map<String, Object>> storeCharge = deliveryDao.getStoreCharge(siteName, nameList);
        res.put("storeDetail", storeDetail);
        res.put("storeCharge", storeCharge);
        return res;
    }

    @Override
    public MaterialReceiveRequest getByKey(String siteName, String receiveRequestName) {
        return deliveryDao.getByKey(siteName, receiveRequestName);
    }

    @Override
    public List<MaterialReceiveRequest> getReceiveByDelivery(String siteName, String receiveRequestName) {
        return deliveryDao.getReceiveByDelivery(siteName, receiveRequestName);
    }

    @Override
    public List<MaterialReceiveRequestDetail> getReceiveDetail(List<String> nameList) {
        return deliveryDao.getReceiveDetail(nameList);
    }
}
